@@ -37,3 +37,7 @@
 /* Default brightness values for the mock backlight used in the test suite */
 #define GSD_MOCK_DEFAULT_BRIGHTNESS                     50
 #define GSD_MOCK_MAX_BRIGHTNESS                        100
+
+/* When unplugging the external monitor, give a certain amount
+ * of time before suspending the laptop */
+#define LID_CLOSE_SAFETY_TIMEOUT                        30 /* seconds */
