@@ -211,6 +211,30 @@ show_offline_updates_error (GsdUpdatesManager *manager)
         g_string_free (msg, TRUE);
 }
 
+static gboolean
+does_gnome_software_exist (void)
+{
+        return g_file_test (BINDIR "/gnome-software", G_FILE_TEST_EXISTS);
+}
+
+static void
+start_gnome_software_with_mode (const gchar *mode)
+{
+        gboolean ret;
+        gchar **argv;
+        GError *error = NULL;
+
+        argv = g_new0 (gchar *, 3);
+        argv[0] = g_build_filename (BINDIR, "gnome-software", NULL);
+        argv[1] = g_strdup_printf ("--mode %s", mode);
+        ret = g_spawn_async (NULL, argv, NULL, 0, NULL, NULL, NULL, &error);
+        if (!ret) {
+                g_warning ("Failed to spawn gnome-software: %s", error->message);
+                g_error_free (error);
+        }
+        g_strfreev (argv);
+}
+
 static void
 libnotify_action_cb (NotifyNotification *notification,
                      gchar *action,
@@ -232,15 +256,23 @@ libnotify_action_cb (NotifyNotification *notification,
                 goto out;
         }
         if (g_strcmp0 (action, "show-update-viewer") == 0) {
-                ret = g_spawn_command_line_async (BINDIR "/gpk-update-viewer",
-                                                  &error);
-                if (!ret) {
-                        g_warning ("Failure launching update viewer: %s",
-                                   error->message);
-                        g_error_free (error);
+                if (does_gnome_software_exist ()) {
+                        start_gnome_software_with_mode ("updates");
+                } else {
+                        ret = g_spawn_command_line_async (BINDIR "/gpk-update-viewer",
+                                                          &error);
+                        if (!ret) {
+                                g_warning ("Failure launching update viewer: %s",
+                                           error->message);
+                                g_error_free (error);
+                        }
                 }
                 goto out;
         }
+        if (g_strcmp0 (action, "review-offline-updates") == 0) {
+                start_gnome_software_with_mode ("updated");
+                goto out;
+        }
         if (g_strcmp0 (action, "clear-offline-updates") == 0) {
                 clear_offline_updates_message ();
                 goto out;
@@ -494,6 +526,8 @@ notify_critical_updates (GsdUpdatesManager *manager, GPtrArray *array)
         }
         /* track so we can prevent doubled notifications */
         manager->priv->notification_updates = notification;
+        g_object_add_weak_pointer (G_OBJECT (manager->priv->notification_updates),
+                                   (void **) &manager->priv->notification_updates);
 }
 
 static void
@@ -562,6 +596,8 @@ notify_normal_updates_maybe (GsdUpdatesManager *manager, GPtrArray *array)
 
         /* track so we can prevent doubled notifications */
         manager->priv->notification_updates = notification;
+        g_object_add_weak_pointer (G_OBJECT (manager->priv->notification_updates),
+                                   (void **) &manager->priv->notification_updates);
 }
 
 static void
@@ -1248,11 +1284,10 @@ check_offline_update_cb (gpointer user_data)
         notify_notification_set_timeout (notification, -1);
         notify_notification_set_urgency (notification, NOTIFY_URGENCY_NORMAL);
         if (success) {
-#if 0
+                if (does_gnome_software_exist ())
                 notify_notification_add_action (notification, "review-offline-updates",
                                                 /* TRANSLATORS: button: review the offline update changes */
                                                 _("Review"), libnotify_action_cb, manager, NULL);
-#endif
         } else {
                 notify_notification_add_action (notification, "error-offline-updates",
                                                 /* TRANSLATORS: button: review the offline update changes */
@@ -1289,8 +1324,10 @@ reboot_failed (GObject *source, GAsyncResult *res, gpointer data)
         GError *error = NULL;
 
         ret = g_dbus_connection_call_finish (G_DBUS_CONNECTION (source), res, &error);
-        if (ret)
+        if (ret) {
                 g_variant_unref (ret);
+                return;
+        }
 
         if (error) {
                 g_warning ("Calling org.gnome.SessionManager.Reboot failed: %s\n", error->message);
@@ -1589,22 +1626,6 @@ gsd_updates_manager_stop (GsdUpdatesManager *manager)
         g_clear_object (&manager->priv->offline_update_error);
 }
 
-static GObject *
-gsd_updates_manager_constructor (
-                GType type,
-                guint n_construct_properties,
-                GObjectConstructParam *construct_properties)
-{
-        GsdUpdatesManager *m;
-
-        m = GSD_UPDATES_MANAGER (G_OBJECT_CLASS (gsd_updates_manager_parent_class)->constructor (
-                                                           type,
-                                                           n_construct_properties,
-                                                           construct_properties));
-
-        return G_OBJECT (m);
-}
-
 static void
 gsd_updates_manager_dispose (GObject *object)
 {
@@ -1622,7 +1643,6 @@ gsd_updates_manager_class_init (GsdUpdatesManagerClass *klass)
 {
         GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-        object_class->constructor = gsd_updates_manager_constructor;
         object_class->dispose = gsd_updates_manager_dispose;
 
         g_type_class_add_private (klass, sizeof (GsdUpdatesManagerPrivate));
